@@ -9,7 +9,7 @@ mod tls_handshake {
     use tls_parser::*;
 
     #[rustfmt::skip]
-static CH : &'static [u8] = &[
+static CH : &[u8] = &[
     0x16, 0x03, 0x01, 0x01, 0x2c, 0x01, 0x00, 0x01, 0x28, 0x03, 0x03, 0xb2,
     0x9d, 0xd7, 0x87, 0xff, 0x21, 0xeb, 0x04, 0xc8, 0xa5, 0x38, 0x39, 0x9a,
     0xcf, 0xb7, 0xa3, 0x82, 0x1f, 0x82, 0x6c, 0x49, 0xbc, 0x8b, 0xb8, 0xa9,
@@ -65,11 +65,11 @@ static CH : &'static [u8] = &[
             msg: vec![TlsMessage::Handshake(TlsMessageHandshake::ClientHello(
                 TlsClientHelloContents {
                     version: TlsVersion::Tls12,
-                    rand_time: 0xb29dd787,
+                    rand_time: 0xb29d_d787,
                     rand_data: &rand_data,
                     session_id: None,
                     ciphers: ciphers.iter().map(|&x| TlsCipherSuiteID(x)).collect(),
-                    comp: comp,
+                    comp,
                     ext: Some(&CH[220..]),
                 },
             ))],
@@ -84,7 +84,7 @@ static CH : &'static [u8] = &[
     // - Server Key Exchange
     // - Server Hello Done
     #[rustfmt::skip]
-static SERVER_REPLY1: &'static [u8] = &[
+static SERVER_REPLY1: &[u8] = &[
     0x16, 0x03, 0x03, 0x00, 0x3b, 0x02, 0x00, 0x00, 0x37, 0x03, 0x03, 0x57,
     0xc4, 0x57, 0xda, 0x9c, 0xd3, 0x24, 0x6d, 0x9d, 0x02, 0x26, 0xa2, 0xe5,
     0x9a, 0xe8, 0xa5, 0x6f, 0x40, 0xad, 0x94, 0x30, 0xba, 0x49, 0x05, 0x3a,
@@ -392,7 +392,7 @@ static SERVER_REPLY1: &'static [u8] = &[
             msg: vec![TlsMessage::Handshake(TlsMessageHandshake::ServerHello(
                 TlsServerHelloContents {
                     version: TlsVersion::Tls12,
-                    rand_time: 0x57c457da,
+                    rand_time: 0x57c4_57da,
                     rand_data: &bytes[15..43],
                     session_id: None,
                     cipher: TlsCipherSuiteID(0xc02f),
@@ -401,7 +401,7 @@ static SERVER_REPLY1: &'static [u8] = &[
                 },
             ))],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[test]
@@ -432,7 +432,7 @@ static SERVER_REPLY1: &'static [u8] = &[
                 TlsCertificateContents { cert_chain: chain },
             ))],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[test]
@@ -451,7 +451,7 @@ static SERVER_REPLY1: &'static [u8] = &[
                 }),
             )],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[test]
@@ -468,7 +468,7 @@ static SERVER_REPLY1: &'static [u8] = &[
                 empty,
             ))],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     // client response, composed of 3 records:
@@ -476,7 +476,7 @@ static SERVER_REPLY1: &'static [u8] = &[
     // - Change Cipher Spec
     // - an encrypted handshake message
     #[rustfmt::skip]
-static CLIENT_REPLY1: &'static [u8] = &[
+static CLIENT_REPLY1: &[u8] = &[
     0x16, 0x03, 0x03, 0x00, 0x46, 0x10, 0x00, 0x00, 0x42, 0x41, 0x04, 0x22,
     0xd3, 0xf9, 0xbf, 0xbb, 0x7e, 0x34, 0xf9, 0x95, 0x68, 0x2e, 0xe2, 0xf8,
     0xf3, 0xf8, 0x08, 0x9c, 0x78, 0x32, 0x81, 0xa8, 0x28, 0x33, 0x5e, 0x46,
@@ -506,7 +506,7 @@ static CLIENT_REPLY1: &'static [u8] = &[
                 )),
             )],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[test]
@@ -521,7 +521,7 @@ static CLIENT_REPLY1: &'static [u8] = &[
             },
             msg: vec![TlsMessage::ChangeCipherSpec],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[test]
@@ -536,11 +536,11 @@ static CLIENT_REPLY1: &'static [u8] = &[
             },
             msg: TlsEncryptedContent { blob: &bytes[5..] },
         };
-        assert_eq!(parse_tls_encrypted(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_encrypted(bytes), Ok((empty, expected)));
     }
 
     #[rustfmt::skip]
-static SERVER_HELLO1: &'static [u8] = &[
+static SERVER_HELLO1: &[u8] = &[
     0x16, 0x03, 0x03, 0x00, 0x3b, 0x02, 0x00, 0x00, 0x37, 0x03, 0x03, 0x57,
     0xc4, 0x57, 0xda, 0x9c, 0xd3, 0x24, 0x6d, 0x9d, 0x02, 0x26, 0xa2, 0xe5,
     0x9a, 0xe8, 0xa5, 0x6f, 0x40, 0xad, 0x94, 0x30, 0xba, 0x49, 0x05, 0x3a,
@@ -554,8 +554,8 @@ static SERVER_HELLO1: &'static [u8] = &[
         let mut v = SERVER_HELLO1.to_vec();
         let bytes = v.as_mut_slice();
         bytes[4] = 0xff; // make record incomplete (longer than data)
-        let expected = Err(Err::Incomplete(Needed::Size(255)));
-        let res = parse_tls_plaintext(&bytes);
+        let expected = Err(Err::Incomplete(Needed::new(196)));
+        let res = parse_tls_plaintext(bytes);
         assert_eq!(res, expected);
     }
 
@@ -564,7 +564,7 @@ static SERVER_HELLO1: &'static [u8] = &[
         let mut v = SERVER_HELLO1.to_vec();
         let bytes = v.as_mut_slice();
         bytes[4] = 0x00; // make record incomplete (shorter than data)
-        let res = parse_tls_plaintext(&bytes);
+        let res = parse_tls_plaintext(bytes);
         assert!(res.is_err());
     }
 
@@ -573,7 +573,7 @@ static SERVER_HELLO1: &'static [u8] = &[
         let mut v = SERVER_HELLO1.to_vec();
         let bytes = v.as_mut_slice();
         bytes[8] = 0xff; // create message larger than record
-        let res = parse_tls_plaintext(&bytes);
+        let res = parse_tls_plaintext(bytes);
         assert!(res.is_err());
     }
 
@@ -582,12 +582,12 @@ static SERVER_HELLO1: &'static [u8] = &[
         let mut v = SERVER_HELLO1.to_vec();
         let bytes = v.as_mut_slice();
         bytes[8] = 0x01; // create message shorter than record
-        let res = parse_tls_plaintext(&bytes);
+        let res = parse_tls_plaintext(bytes);
         assert!(res.is_err());
     }
 
     #[rustfmt::skip]
-static SERVER_CERTIFICATE_REQUEST_NOCA: &'static [u8] = &[
+static SERVER_CERTIFICATE_REQUEST_NOCA: &[u8] = &[
     0x16, 0x03, 0x03, 0x00, 0x2a, 0x0d, 0x00, 0x00, 0x26, 0x03, 0x01, 0x02,
     0x40, 0x00, 0x1e, 0x06, 0x01, 0x06, 0x02, 0x06, 0x03, 0x05, 0x01, 0x05,
     0x02, 0x05, 0x03, 0x04, 0x01, 0x04, 0x02, 0x04, 0x03, 0x03, 0x01, 0x03,
@@ -615,11 +615,11 @@ static SERVER_CERTIFICATE_REQUEST_NOCA: &'static [u8] = &[
                 }),
             )],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[rustfmt::skip]
-static SERVER_CERTIFICATE_REQUEST_CA: &'static [u8] = &[
+static SERVER_CERTIFICATE_REQUEST_CA: &[u8] = &[
     0x16, 0x03, 0x03, 0x00, 0x73, 0x0d, 0x00, 0x00, 0x6f, 0x03, 0x01, 0x02,
     0x40, 0x00, 0x1e, 0x06, 0x01, 0x06, 0x02, 0x06, 0x03, 0x05, 0x01, 0x05,
     0x02, 0x05, 0x03, 0x04, 0x01, 0x04, 0x02, 0x04, 0x03, 0x03, 0x01, 0x03,
@@ -654,11 +654,11 @@ static SERVER_CERTIFICATE_REQUEST_CA: &'static [u8] = &[
                 }),
             )],
         };
-        assert_eq!(parse_tls_plaintext(&bytes), Ok((empty, expected)));
+        assert_eq!(parse_tls_plaintext(bytes), Ok((empty, expected)));
     }
 
     #[rustfmt::skip]
-static SERVER_STATUS_RESPONSE: &'static [u8] = &[
+static SERVER_STATUS_RESPONSE: &[u8] = &[
     0x16, 0x00, 0x06, 0x3f, 0x01, 0x00, 0x06, 0x3b, 0x30, 0x82, 0x06, 0x37,
     0x0a, 0x01, 0x00, 0xa0, 0x82, 0x06, 0x30, 0x30, 0x82, 0x06, 0x2c, 0x06,
     0x09, 0x2b, 0x06, 0x01, 0x05, 0x05, 0x07, 0x30, 0x01, 0x01, 0x04, 0x82,
@@ -803,7 +803,7 @@ static SERVER_STATUS_RESPONSE: &'static [u8] = &[
         let expected = vec![TlsMessage::Handshake(
             TlsMessageHandshake::CertificateStatus(TlsCertificateStatusContents {
                 status_type: 1,
-                blob: blob,
+                blob,
             }),
         )];
         let hdr = TlsRecordHeader {
@@ -811,7 +811,7 @@ static SERVER_STATUS_RESPONSE: &'static [u8] = &[
             version: TlsVersion(0),
             len: 0x0,
         };
-        let res = parse_tls_record_with_header(&bytes, &hdr);
+        let res = parse_tls_record_with_header(bytes, &hdr);
         assert_eq!(res, Ok((empty, expected)));
     }
 } // mod tls_handshake
